#!/bin/sh

accounts=$(whmapi1 --output=jsonpretty listaccts | jq -r '.data.acct[] | .user' | sort)

whmapi1 --output=jsonpretty get_disk_usage > /root/disk_usage.txt
whmapi1 --output=jsonpretty showbw > /root/bw_limit.txt

echo ''

printf "%-20s %-20s %-20s %-20s\n" "Account" "Disk_Limit / Package" "BW_Limit / Package" "Package"

printf "%-20s %-20s %-20s %-20s\n" "-------------------" "--------------------" "------------------" "-------------------"

for account in $accounts; do

  if [ "$account" == "phpchk" ]; then
      continue
  fi

  disk_limit=`cat /root/disk_usage.txt | jq --arg account "$account" '.data.accounts[] | select(.user == $account) | .blocks_limit'`
  if [ "$disk_limit" != "null" ]; then
    disk_limit=$(expr $(echo $disk_limit | sed 's/\"//g') \/ 1024)
  fi

  bw_limit=`cat /root/bw_limit.txt | jq --arg account $account '.data.acct[] | select(.user == $account) | .limit'`
  if [ "$bw_limit" != "\"unlimited\"" ]; then
    bw_limit=$(expr $(echo $bw_limit | sed 's/\"//g') \/ 1024 \/ 1024)
  else
    bw_limit='unlimited'
  fi

  account_pkg=`cat /var/cpanel/users/$account | grep PLAN | awk -F\= '{print $2}'`

  if [ "$account_pkg" == "undefined" ]; then
      continue
  fi
  if [ ! -e /var/cpanel/packages/$account_pkg ]; then
      echo "Account $account 使用 $account_pkg 方案不存在"
      continue
  fi

  disk_pkg=`cat /var/cpanel/packages/$account_pkg | grep ^QUOTA | awk -F\= '{print $2}'`
  bw_pkg=`cat /var/cpanel/packages/$account_pkg | grep ^BWLIMIT | awk -F\= '{print $2}'`

  if [ "$disk_limit" != "$disk_pkg" ] || [ "$bw_limit" != "$bw_pkg" ]; then
    printf "%-20s %-20s %-20s %-20s\n" "$account" "$disk_limit / $disk_pkg" "$bw_limit / $bw_pkg" "$account_pkg"
  fi

done

echo ''

rm -f /root/disk_usage.txt
rm -f /root/bw_limit.txt
